==> xlniuxdata-vipgame-1.0.33-20151112.053636-31-sources.jar: com/xunlei/niux/data/vipgame/vo/business/Income.java <==
package com.xunlei.niux.data.vipgame.vo.business;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

import java.math.BigDecimal;

/**
 * @author hezhong
 */
@Table(tableName = "income", pkFieldName = "seqid", pkFieldAssign = false)
public class Income {

    private Integer seqid;

    private String gameid;

    private String incomemonth;

    private BigDecimal total;

    private BigDecimal secondprincipal;

    private BigDecimal firstprincipal;

    private BigDecimal money;

    private String remark;

    @Column(columnName="incomemonth",isWhereColumn=true,operator= Operator.GE)
    private String fromMonth;

    @Column(columnName="incomemonth",isWhereColumn=true,operator=Operator.LT)
    private String toMonth;

    public String getFromMonth() {
        return fromMonth;
    }

    public void setFromMonth(String fromMonth) {
        this.fromMonth = fromMonth;
    }

    public String getToMonth() {
        return toMonth;
    }

    public void setToMonth(String toMonth) {
        this.toMonth = toMonth;
    }

    public Integer getSeqid() {
        return seqid;
    }

    public void setSeqid(Integer seqid) {
        this.seqid = seqid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public String getIncomemonth() {
        return incomemonth;
    }

    public void setIncomemonth(String incomemonth) {
        this.incomemonth = incomemonth;
    }

    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }

    public BigDecimal getSecondprincipal() {
        return secondprincipal;
    }

    public void setSecondprincipal(BigDecimal secondprincipal) {
        this.secondprincipal = secondprincipal;
    }

    public BigDecimal getFirstprincipal() {
        return firstprincipal;
    }

    public void setFirstprincipal(BigDecimal firstprincipal) {
        this.firstprincipal = firstprincipal;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170705.060154-89-sources.jar: com/xunlei/niux/data/vipgame/vo/business/Income.java <==
package com.xunlei.niux.data.vipgame.vo.business;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

import java.math.BigDecimal;

/**
 * @author hezhong
 */
@Table(tableName = "income", pkFieldName = "seqid", pkFieldAssign = false)
public class Income {

    private Integer seqid;

    private String gameid;

    private String incomemonth;

    private BigDecimal total;

    private BigDecimal secondprincipal;

    private BigDecimal firstprincipal;

    private BigDecimal money;

    private String remark;

    @Column(columnName="incomemonth",isWhereColumn=true,operator= Operator.GE)
    private String fromMonth;

    @Column(columnName="incomemonth",isWhereColumn=true,operator=Operator.LT)
    private String toMonth;
    
    private BigDecimal cashVoucher;

    public String getFromMonth() {
        return fromMonth;
    }

    public void setFromMonth(String fromMonth) {
        this.fromMonth = fromMonth;
    }

    public String getToMonth() {
        return toMonth;
    }

    public void setToMonth(String toMonth) {
        this.toMonth = toMonth;
    }

    public Integer getSeqid() {
        return seqid;
    }

    public void setSeqid(Integer seqid) {
        this.seqid = seqid;
    }

    public String getGameid() {
        return gameid;
    }

    public void setGameid(String gameid) {
        this.gameid = gameid;
    }

    public String getIncomemonth() {
        return incomemonth;
    }

    public void setIncomemonth(String incomemonth) {
        this.incomemonth = incomemonth;
    }

    public BigDecimal getTotal() {
        return total;
    }

    public void setTotal(BigDecimal total) {
        this.total = total;
    }

    public BigDecimal getSecondprincipal() {
        return secondprincipal;
    }

    public void setSecondprincipal(BigDecimal secondprincipal) {
        this.secondprincipal = secondprincipal;
    }

    public BigDecimal getFirstprincipal() {
        return firstprincipal;
    }

    public void setFirstprincipal(BigDecimal firstprincipal) {
        this.firstprincipal = firstprincipal;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public BigDecimal getCashVoucher() {
		return cashVoucher;
	}

	public void setCashVoucher(BigDecimal cashVoucher) {
		this.cashVoucher = cashVoucher;
	}
}
